/********************************************************************************
** Form generated from reading UI file 'contactgroupeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONTACTGROUPEDITOR_H
#define UI_CONTACTGROUPEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ContactGroupEditor
{
public:
    QGridLayout *gridLayout;
    QLabel *groupNameLabel;
    KLineEdit *groupName;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    KLineEdit *searchField;
    QTreeView *membersView;

    void setupUi(QWidget *ContactGroupEditor)
    {
        if (ContactGroupEditor->objectName().isEmpty())
            ContactGroupEditor->setObjectName("ContactGroupEditor");
        ContactGroupEditor->resize(392, 289);
        gridLayout = new QGridLayout(ContactGroupEditor);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        groupNameLabel = new QLabel(ContactGroupEditor);
        groupNameLabel->setObjectName("groupNameLabel");

        gridLayout->addWidget(groupNameLabel, 0, 0, 1, 1);

        groupName = new KLineEdit(ContactGroupEditor);
        groupName->setObjectName("groupName");
        groupName->setProperty("trapEnterKeyEvent", QVariant(true));

        gridLayout->addWidget(groupName, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 1, 1, 1);

        label = new QLabel(ContactGroupEditor);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 2);

        searchField = new KLineEdit(ContactGroupEditor);
        searchField->setObjectName("searchField");
        searchField->setClearButtonEnabled(true);
        searchField->setProperty("trapEnterKeyEvent", QVariant(true));

        gridLayout->addWidget(searchField, 3, 0, 1, 2);

        membersView = new QTreeView(ContactGroupEditor);
        membersView->setObjectName("membersView");
        membersView->setRootIsDecorated(false);
        membersView->setItemsExpandable(false);
        membersView->setAllColumnsShowFocus(true);

        gridLayout->addWidget(membersView, 4, 0, 1, 2);


        retranslateUi(ContactGroupEditor);

        QMetaObject::connectSlotsByName(ContactGroupEditor);
    } // setupUi

    void retranslateUi(QWidget *ContactGroupEditor)
    {
        groupNameLabel->setText(tr2i18n("Name:", "@label The name of a contact group"));
        label->setText(tr2i18n("Contact group members:", "@label"));
        searchField->setPlaceholderText(tr2i18n("Search...", nullptr));
        (void)ContactGroupEditor;
    } // retranslateUi

};

namespace Ui {
    class ContactGroupEditor: public Ui_ContactGroupEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONTACTGROUPEDITOR_H

