/*
    SPDX-FileCopyrightText: 2008 Tobias Koenig <tokoe@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "contactparts.h"

const char Akonadi::ContactPart::Lookup[] = "CONTACT_LOOKUP";
const char Akonadi::ContactPart::Standard[] = "CONTACT_STANDARD";
