/****************************************************************************
** Meta object code from reading C++ file 'contactgrantleewrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-contacts-26.07.90/src/akonadi-contacts-core/grantlee/contactgrantleewrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'contactgrantleewrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto KAddressBookGrantlee::ContactGrantleeWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAddressBookGrantlee::ContactGrantleeWrapper",
        "addressBookLabel",
        "anniversaryLabel",
        "assistantLabel",
        "birthdayLabel",
        "departmentLabel",
        "noteLabel",
        "managerLabel",
        "officeLabel",
        "professionLabel",
        "spouseLabel",
        "addressBookName",
        "age",
        "photo",
        "logo",
        "formattedBirthday",
        "formattedAnniversary"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'addressBookLabel'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'anniversaryLabel'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'assistantLabel'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'birthdayLabel'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'departmentLabel'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'noteLabel'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'managerLabel'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'officeLabel'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'professionLabel'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'spouseLabel'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'addressBookName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'age'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'photo'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'logo'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'formattedBirthday'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'formattedAnniversary'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContactGrantleeWrapper, qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAddressBookGrantlee::ContactGrantleeWrapper::staticMetaObject = { {
    QtPrivate::MetaObjectForType<KContacts::Addressee>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KAddressBookGrantlee22ContactGrantleeWrapperE_t>.metaTypes,
    nullptr
} };

void KAddressBookGrantlee::ContactGrantleeWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ContactGrantleeWrapper *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->addressBookLabel(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->anniversaryLabel(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->assistantLabel(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->birthdayLabel(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->departmentLabel(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->noteLabel(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->managerLabel(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->officeLabel(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->professionLabel(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->spouseLabel(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->addressBookName(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->age(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->photoImgElement(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->logoImgElement(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->formattedBirthday(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->formattedAnniversary(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
